==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDetailDescription } from "./WebColumnVisibilityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "Unknown");
            a.item("NewValue", "Boolean");
        }
        static d(a) {
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebColumnVisibilityChangedEventArgsDetail", () => new WebColumnVisibilityChangedEventArgsDetailDescription());
            a.ac("WebColumnVisibilityChangedEventArgsDetail", WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDetailDescription } from "./WebColumnVisibilityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "Unknown");
            a.item("NewValue", "Boolean");
        }
        static d(a) {
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebColumnVisibilityChangedEventArgsDetail", () => new WebColumnVisibilityChangedEventArgsDetailDescription());
            a.ad("WebColumnVisibilityChangedEventArgsDetail", WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata;
})();
